@@ -2,7 +2,17 @@ import enum
 from datetime import datetime
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-from pydantic import BaseModel, Extra, Field, constr, validator
+from pydantic import (
+    BaseModel,
+    Extra,
+    Field,
+    StrictBool,
+    StrictFloat,
+    StrictInt,
+    StrictStr,
+    constr,
+    validator,
+)
 
 
 class Model(BaseModel):
@@ -11,6 +21,7 @@ class Model(BaseModel):
 
 
 UserMetadataKey = constr(regex=r"^\w+$")
+UserMetadataValue = Union[StrictBool, StrictInt, StrictFloat, StrictStr]
 
 
 class BaseElement(Model):
@@ -29,7 +40,7 @@ class BaseElement(Model):
     group_uid: Optional[str] = Field(
         None, description="UID of group to which link belongs"
     )
-    user_metadata: Optional[Dict[UserMetadataKey, Union[float, str]]] = Field(
+    user_metadata: Optional[Dict[UserMetadataKey, UserMetadataValue]] = Field(
         None, description="Optional dictionary of user-provided key-value pairs"
     )
 
